Filters (``zarr.filters``)
==========================
.. module:: zarr.filters

.. autoclass:: DeltaFilter
.. autoclass:: FixedScaleOffsetFilter
.. autoclass:: QuantizeFilter
.. autoclass:: PackBitsFilter
.. autoclass:: CategoryFilter
